@@ -527,7 +527,7 @@ class LogicAppPipelineConfigManager:
         # declaration of file name that will contain the endpoint that has just been published.
         #self.REMOTE_FILE_NAME = "published_pipeline.json"
         # declaration of container (or folder) which will contain the json file
-        self.BLOB_CONTAINER = "{0}/configs".format(config.CONTAINER_NAME)
+        self.BLOB_CONTAINER = "{0}/{1}/configs".format(config.CONTAINER_NAME, config.ENV_DIR)
         #http link where the json file will be deposited
         #self.file_url = "https://humlstorage.blob.core.windows.net/{0}/{1}".format(self.BLOB_CONTAINER,self.REMOTE_FILE_NAME)
     
@@ -720,6 +720,19 @@ class ConfigProvider:
     
     def load(self):
         data = self._load_data()
+
+        #StorageAccount
+        self.BLOB_DATASTORE_NAME = data["Azure"]["StorageAccount"]["BlobDatastoreName"]
+        self.ACCOUNT_NAME = data["Azure"]["StorageAccount"]["AccountName"]
+        self.CONTAINER_NAME = data["Azure"]["StorageAccount"]["ContainerName"]
+        self.ENV_DIR = data["Azure"]["StorageAccount"]["EnvDir"]
+        self.ACCOUNT_KEY = data["Azure"]["StorageAccount"]["AccountKey"]
+        self.BLOB_STORAGE_CONNECTION_STRING = data["Azure"]["StorageAccount"]["BlobStorageConnectionString"]
+        #Azureml
+        self.LOCATION = data["Azure"]["Azureml"]["Location"]
+        self.RESOURCEGROUP = data["Azure"]["Azureml"]["ResourceGroup"]
+        self.WORKSPACENAME = data["Azure"]["Azureml"]["WorkspaceName"]
+
         #ApplicationInsights
         self.APPLICATION_INSIGHTS_CONNECTION_STRING = data["Azure"]["ApplicationInsights"]["ConnectionString"]
 
@@ -878,7 +891,7 @@ class PipelineEndpointLauncher:
 
 class TextSampledDataBuilder:
     def build(self, sampled_data):
-        assert(isinstance(sampled_data, list) == True, "sampled_data must be a list")
+        assert isinstance(sampled_data, list), "sampled_data must be a list"
         samped_json_data = []
         for item in sampled_data:
             json_data = {}
@@ -900,16 +913,17 @@ class SampledDataDispatcher:
                                     number_files,
                                         sampled_data_builder,
                                                     blob_manager):
-
-        assert(isinstance(sampled_data, list) == True, "sampled_data must be a list")
+        
+        assert isinstance(sampled_data, list), "sampled_data must be a list"
         for item_to_check in sampled_data:
-            assert(isinstance(item_to_check, list) == True, "item in list sampled_data must be a list")
-            assert(len(item_to_check) == 5, "item in list sampled_data must  must have 5 elements")
-        assert(number_files <= len(sampled_data), "number_files must be less than " + len(sampled_data))
+            assert isinstance(item_to_check, list), "item in list sampled_data must be a list"
+            assert len(item_to_check) == 5, "item in list sampled_data must  must have 5 elements"
+        assert number_files <= len(sampled_data), "number_files must be less than " + len(sampled_data)
 
         splitted_data = np.array_split(sampled_data, number_files)
         for index, data in enumerate(splitted_data):
-            samped_json_data = sampled_data_builder.build(data)
+            print("type(data) :", type(data))
+            samped_json_data = sampled_data_builder.build(data.tolist())
             
             part_path = "part_{0}".format(index)
             sampled_item_folder = os.path.join(sampled_folder, part_path)
@@ -920,9 +934,11 @@ class SampledDataDispatcher:
                 json.dump(samped_json_data, write_file)
 
             #create sampled_meta_data json file
+            #time.time.strftime(r"%d/%m/%Y %H:%M:%S", time.time.localtime())
+            today = datetime.now()
             meta_json_data = {}
             meta_json_data["userid"] = ""
-            meta_json_data["creationDate"] = datetime.now.strftime("%d/%m/%Y %H:%M:%S")
+            meta_json_data["creationDate"] = today.strftime("%d/%m/%Y %H:%M:%S")
             meta_json_data["modificationDate"] = ""
             meta_json_data["status"] = "created" #progressing, completed
             meta_json_data["isLocked"] = False
